# Generated by Django 3.2.7 on 2022-06-14 16:01

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('app', '0004_auto_20220614_0619'),
    ]

    operations = [
        migrations.AlterField(
            model_name='workorder',
            name='generalStatus',
            field=models.CharField(blank=True, db_column='generalStatus', max_length=30, null=True),
        ),
        migrations.AlterField(
            model_name='workorder',
            name='paymentJson',
            field=models.JSONField(blank=True, db_column='paymentJson', null=True),
        ),
        migrations.AlterField(
            model_name='workorder',
            name='transactionReference',
            field=models.TextField(blank=True, db_column='transactionReference', max_length=255, null=True),
        ),
    ]
