# Generated by Django 3.2.7 on 2022-06-26 15:53

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('app', '0011_auto_20220626_1643'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='workorder',
            name='paymentJson',
        ),
        migrations.AddField(
            model_name='workorder',
            name='latitude',
            field=models.CharField(default='0', max_length=30),
        ),
        migrations.AddField(
            model_name='workorder',
            name='longitude',
            field=models.CharField(default='0', max_length=30),
        ),
        migrations.AlterField(
            model_name='workorder',
            name='address',
            field=models.TextField(default=''),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name='workorder',
            name='agentArrived',
            field=models.BooleanField(db_column='agentArrived', default=False),
        ),
        migrations.AlterField(
            model_name='workorder',
            name='agentEnroute',
            field=models.BooleanField(db_column='agentEnroute', default=False),
        ),
        migrations.AlterField(
            model_name='workorder',
            name='currentStatus',
            field=models.CharField(db_column='currentStatus', default='unAssigned', max_length=30),
        ),
        migrations.AlterField(
            model_name='workorder',
            name='customerCompletionConfirmation',
            field=models.BooleanField(db_column='customerCompletionConfirmation', default=False),
        ),
        migrations.AlterField(
            model_name='workorder',
            name='isAssessmentCompleted',
            field=models.BooleanField(db_column='isAssessmentCompleted', default=False),
        ),
        migrations.AlterField(
            model_name='workorder',
            name='isCommitmentFeePaid',
            field=models.BooleanField(db_column='isCommitmentFeePaid', default=False),
        ),
        migrations.AlterField(
            model_name='workorder',
            name='paymentCompleted',
            field=models.BooleanField(db_column='paymentCompleted', default=False),
        ),
    ]
