# Generated by Django 3.2.7 on 2022-06-14 06:19

from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('app', '0003_auto_20220614_0550'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='workorderservicecategory',
            name='serviceId',
        ),
        migrations.AddField(
            model_name='workorderservicecategory',
            name='service',
            field=models.ForeignKey(blank=True, db_column='service', null=True, on_delete=django.db.models.deletion.SET_NULL, to='app.workorderservice'),
        ),
        migrations.AlterField(
            model_name='workorderservicecategory',
            name='chargeType',
            field=models.CharField(blank=True, db_column='chargeType', max_length=30, null=True),
        ),
        migrations.AlterField(
            model_name='workorderservicecategory',
            name='name',
            field=models.CharField(default=django.utils.timezone.now, max_length=255),
            preserve_default=False,
        ),
    ]
