# Generated by Django 3.2.7 on 2022-07-04 16:37

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('app', '0014_meterrequest_orderid'),
    ]

    operations = [
        migrations.AddField(
            model_name='meterrequest',
            name='status',
            field=models.CharField(default='new', max_length=15),
        ),
    ]
