# Generated by Django 3.2.7 on 2022-06-25 00:02

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('app', '0009_auto_20220624_2026'),
    ]

    operations = [
        migrations.AlterField(
            model_name='config',
            name='service',
            field=models.CharField(choices=[('msh', 'msh'), ('payment', 'payment'), ('inventory', 'inventory'), ('customer', 'customer')], max_length=50),
        ),
    ]
