# Generated by Django 3.2.7 on 2022-06-23 03:23

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('app', '0007_auto_20220617_2252'),
    ]

    operations = [
        migrations.CreateModel(
            name='Config',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('service', models.CharField(choices=[('msh', 'msh'), ('payment', 'payment'), ('inventory', 'inventory'), ('customer', 'customer')], max_length=50, unique=True)),
                ('key', models.CharField(max_length=50, unique=True)),
                ('value', models.CharField(max_length=100)),
                ('date_created', models.DateTimeField(auto_now_add=True)),
                ('date_updated', models.DateTimeField(auto_now=True)),
                ('last_updated_by', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.RemoveField(
            model_name='payment',
            name='paymentType',
        ),
        migrations.RemoveField(
            model_name='paymentvendor',
            name='credential',
        ),
        migrations.RemoveField(
            model_name='paymentvendor',
            name='paths',
        ),
        migrations.RemoveField(
            model_name='paymentvendor',
            name='url',
        ),
        migrations.RemoveField(
            model_name='transactionlog',
            name='paymentType',
        ),
        migrations.RemoveField(
            model_name='workorder',
            name='paymentType',
        ),
        migrations.AlterField(
            model_name='paymentvendor',
            name='name',
            field=models.CharField(blank=True, max_length=30, null=True),
        ),
        migrations.AlterField(
            model_name='paymentvendor',
            name='ref',
            field=models.CharField(blank=True, max_length=30, null=True),
        ),
        migrations.AlterField(
            model_name='paymentvendor',
            name='type',
            field=models.CharField(blank=True, max_length=30, null=True),
        ),
        migrations.DeleteModel(
            name='PaymentType',
        ),
    ]
