# Generated by Django 3.2.7 on 2022-06-15 07:14

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone
import uuid


class Migration(migrations.Migration):

    dependencies = [
        ('app', '0005_auto_20220614_1601'),
    ]

    operations = [
        migrations.AddField(
            model_name='user',
            name='locationLatitude',
            field=models.FloatField(default=0),
        ),
        migrations.AddField(
            model_name='user',
            name='locationLongitude',
            field=models.FloatField(default=0),
        ),
        migrations.AddField(
            model_name='workorder',
            name='createdAt',
            field=models.DateTimeField(auto_now_add=True, db_column='createdAt', default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='workorder',
            name='createdBy',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='workorder',
            name='currentStatus',
            field=models.CharField(db_column='currentStatus', default='unPaid', max_length=30),
        ),
        migrations.AddField(
            model_name='workorder',
            name='deleted',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='workorder',
            name='deletedAt',
            field=models.DateTimeField(blank=True, db_column='deletedAt', null=True),
        ),
        migrations.AddField(
            model_name='workorder',
            name='deletedById',
            field=models.UUIDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='workorder',
            name='deletedViaCascade',
            field=models.BooleanField(default=False, editable=False),
        ),
        migrations.AddField(
            model_name='workorder',
            name='uid',
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
        migrations.AddField(
            model_name='workorder',
            name='updatedAt',
            field=models.DateTimeField(auto_now=True, db_column='updatedAt'),
        ),
        migrations.AlterField(
            model_name='workorder',
            name='generalStatus',
            field=models.CharField(db_column='generalStatus', default='new', max_length=30),
        ),
    ]
