# Generated by Django 3.2.7 on 2022-06-28 17:15

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('app', '0012_auto_20220626_1653'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='wallet',
            name='name',
        ),
        migrations.RemoveField(
            model_name='wallet',
            name='recipient',
        ),
        migrations.RemoveField(
            model_name='wallet',
            name='recipientCode',
        ),
        migrations.RemoveField(
            model_name='wallethistory',
            name='isCompleted',
        ),
        migrations.RemoveField(
            model_name='wallethistory',
            name='requestJson',
        ),
        migrations.RemoveField(
            model_name='wallethistory',
            name='transferCode',
        ),
        migrations.AddField(
            model_name='wallethistory',
            name='balanceAfter',
            field=models.DecimalField(decimal_places=2, default=0, max_digits=15),
        ),
        migrations.AddField(
            model_name='wallethistory',
            name='balanceBefore',
            field=models.DecimalField(decimal_places=2, default=0, max_digits=15),
        ),
        migrations.AddField(
            model_name='wallethistory',
            name='isSuccessful',
            field=models.BooleanField(db_column='isSuccessful', default=False),
        ),
        migrations.AddField(
            model_name='wallethistory',
            name='transactionLog',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='app.transactionlog'),
        ),
        migrations.AddField(
            model_name='wallethistory',
            name='workOrder',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='app.workorder'),
        ),
        migrations.AlterField(
            model_name='wallethistory',
            name='type',
            field=models.CharField(blank=True, choices=[('earnings', 'earnings'), ('deposit', 'deposit'), ('withdrawal', 'withdrawal')], max_length=30, null=True),
        ),
        migrations.DeleteModel(
            name='Earning',
        ),
    ]
