# Generated by Django 3.2.7 on 2022-06-14 04:56

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone
import uuid


class Migration(migrations.Migration):

    dependencies = [
        ('app', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='card',
            name='createdAt',
            field=models.DateTimeField(auto_now_add=True, db_column='createdAt', default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='card',
            name='createdBy',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='card',
            name='deleted',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='card',
            name='deletedAt',
            field=models.DateTimeField(blank=True, db_column='deletedAt', null=True),
        ),
        migrations.AddField(
            model_name='card',
            name='deletedById',
            field=models.UUIDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='card',
            name='deletedViaCascade',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='card',
            name='uid',
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
        migrations.AddField(
            model_name='card',
            name='updatedAt',
            field=models.DateTimeField(auto_now=True, db_column='updatedAt'),
        ),
        migrations.AddField(
            model_name='cart',
            name='createdAt',
            field=models.DateTimeField(auto_now_add=True, db_column='createdAt', default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='cart',
            name='createdBy',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='cart',
            name='deleted',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='cart',
            name='deletedAt',
            field=models.DateTimeField(blank=True, db_column='deletedAt', null=True),
        ),
        migrations.AddField(
            model_name='cart',
            name='deletedById',
            field=models.UUIDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='cart',
            name='deletedViaCascade',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='cart',
            name='uid',
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
        migrations.AddField(
            model_name='cart',
            name='updatedAt',
            field=models.DateTimeField(auto_now=True, db_column='updatedAt'),
        ),
        migrations.AddField(
            model_name='conversation',
            name='createdAt',
            field=models.DateTimeField(auto_now_add=True, db_column='createdAt', default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='conversation',
            name='createdBy',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='conversation',
            name='deleted',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='conversation',
            name='deletedAt',
            field=models.DateTimeField(blank=True, db_column='deletedAt', null=True),
        ),
        migrations.AddField(
            model_name='conversation',
            name='deletedById',
            field=models.UUIDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='conversation',
            name='deletedViaCascade',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='conversation',
            name='uid',
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
        migrations.AddField(
            model_name='conversation',
            name='updatedAt',
            field=models.DateTimeField(auto_now=True, db_column='updatedAt'),
        ),
        migrations.AddField(
            model_name='disco',
            name='createdAt',
            field=models.DateTimeField(auto_now_add=True, db_column='createdAt', default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='disco',
            name='createdBy',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='disco',
            name='deleted',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='disco',
            name='deletedAt',
            field=models.DateTimeField(blank=True, db_column='deletedAt', null=True),
        ),
        migrations.AddField(
            model_name='disco',
            name='deletedById',
            field=models.UUIDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='disco',
            name='deletedViaCascade',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='disco',
            name='uid',
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
        migrations.AddField(
            model_name='disco',
            name='updatedAt',
            field=models.DateTimeField(auto_now=True, db_column='updatedAt'),
        ),
        migrations.AddField(
            model_name='document',
            name='createdAt',
            field=models.DateTimeField(auto_now_add=True, db_column='createdAt', default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='document',
            name='createdBy',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='document',
            name='deleted',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='document',
            name='deletedAt',
            field=models.DateTimeField(blank=True, db_column='deletedAt', null=True),
        ),
        migrations.AddField(
            model_name='document',
            name='deletedById',
            field=models.UUIDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='document',
            name='deletedViaCascade',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='document',
            name='uid',
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
        migrations.AddField(
            model_name='document',
            name='updatedAt',
            field=models.DateTimeField(auto_now=True, db_column='updatedAt'),
        ),
        migrations.AddField(
            model_name='documentation',
            name='createdAt',
            field=models.DateTimeField(auto_now_add=True, db_column='createdAt', default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='documentation',
            name='createdBy',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='documentation',
            name='deleted',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='documentation',
            name='deletedAt',
            field=models.DateTimeField(blank=True, db_column='deletedAt', null=True),
        ),
        migrations.AddField(
            model_name='documentation',
            name='deletedById',
            field=models.UUIDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='documentation',
            name='deletedViaCascade',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='documentation',
            name='uid',
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
        migrations.AddField(
            model_name='documentation',
            name='updatedAt',
            field=models.DateTimeField(auto_now=True, db_column='updatedAt'),
        ),
        migrations.AddField(
            model_name='expertise',
            name='createdAt',
            field=models.DateTimeField(auto_now_add=True, db_column='createdAt', default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='expertise',
            name='createdBy',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='expertise',
            name='deleted',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='expertise',
            name='deletedAt',
            field=models.DateTimeField(blank=True, db_column='deletedAt', null=True),
        ),
        migrations.AddField(
            model_name='expertise',
            name='deletedById',
            field=models.UUIDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='expertise',
            name='deletedViaCascade',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='expertise',
            name='uid',
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
        migrations.AddField(
            model_name='expertise',
            name='updatedAt',
            field=models.DateTimeField(auto_now=True, db_column='updatedAt'),
        ),
        migrations.AddField(
            model_name='meansofidentification',
            name='createdAt',
            field=models.DateTimeField(auto_now_add=True, db_column='createdAt', default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='meansofidentification',
            name='createdBy',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='meansofidentification',
            name='deleted',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='meansofidentification',
            name='deletedAt',
            field=models.DateTimeField(blank=True, db_column='deletedAt', null=True),
        ),
        migrations.AddField(
            model_name='meansofidentification',
            name='deletedById',
            field=models.UUIDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='meansofidentification',
            name='deletedViaCascade',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='meansofidentification',
            name='uid',
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
        migrations.AddField(
            model_name='meansofidentification',
            name='updatedAt',
            field=models.DateTimeField(auto_now=True, db_column='updatedAt'),
        ),
        migrations.AddField(
            model_name='message',
            name='createdAt',
            field=models.DateTimeField(auto_now_add=True, db_column='createdAt', default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='message',
            name='createdBy',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='message',
            name='deleted',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='message',
            name='deletedAt',
            field=models.DateTimeField(blank=True, db_column='deletedAt', null=True),
        ),
        migrations.AddField(
            model_name='message',
            name='deletedById',
            field=models.UUIDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='message',
            name='deletedViaCascade',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='message',
            name='uid',
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
        migrations.AddField(
            model_name='message',
            name='updatedAt',
            field=models.DateTimeField(auto_now=True, db_column='updatedAt'),
        ),
        migrations.AddField(
            model_name='meterrequest',
            name='createdAt',
            field=models.DateTimeField(auto_now_add=True, db_column='createdAt', default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='meterrequest',
            name='createdBy',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='meterrequest',
            name='deleted',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='meterrequest',
            name='deletedAt',
            field=models.DateTimeField(blank=True, db_column='deletedAt', null=True),
        ),
        migrations.AddField(
            model_name='meterrequest',
            name='deletedById',
            field=models.UUIDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='meterrequest',
            name='deletedViaCascade',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='meterrequest',
            name='uid',
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
        migrations.AddField(
            model_name='meterrequest',
            name='updatedAt',
            field=models.DateTimeField(auto_now=True, db_column='updatedAt'),
        ),
        migrations.AddField(
            model_name='nextofkin',
            name='createdAt',
            field=models.DateTimeField(auto_now_add=True, db_column='createdAt', default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='nextofkin',
            name='createdBy',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='nextofkin',
            name='deleted',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='nextofkin',
            name='deletedAt',
            field=models.DateTimeField(blank=True, db_column='deletedAt', null=True),
        ),
        migrations.AddField(
            model_name='nextofkin',
            name='deletedById',
            field=models.UUIDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='nextofkin',
            name='deletedViaCascade',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='nextofkin',
            name='uid',
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
        migrations.AddField(
            model_name='nextofkin',
            name='updatedAt',
            field=models.DateTimeField(auto_now=True, db_column='updatedAt'),
        ),
        migrations.AddField(
            model_name='payment',
            name='createdAt',
            field=models.DateTimeField(auto_now_add=True, db_column='createdAt', default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='payment',
            name='createdBy',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='payment',
            name='deleted',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='payment',
            name='deletedAt',
            field=models.DateTimeField(blank=True, db_column='deletedAt', null=True),
        ),
        migrations.AddField(
            model_name='payment',
            name='deletedById',
            field=models.UUIDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='payment',
            name='deletedViaCascade',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='payment',
            name='uid',
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
        migrations.AddField(
            model_name='payment',
            name='updatedAt',
            field=models.DateTimeField(auto_now=True, db_column='updatedAt'),
        ),
        migrations.AddField(
            model_name='paymenttype',
            name='createdAt',
            field=models.DateTimeField(auto_now_add=True, db_column='createdAt', default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='paymenttype',
            name='createdBy',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='paymenttype',
            name='deleted',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='paymenttype',
            name='deletedAt',
            field=models.DateTimeField(blank=True, db_column='deletedAt', null=True),
        ),
        migrations.AddField(
            model_name='paymenttype',
            name='deletedById',
            field=models.UUIDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='paymenttype',
            name='deletedViaCascade',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='paymenttype',
            name='uid',
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
        migrations.AddField(
            model_name='paymenttype',
            name='updatedAt',
            field=models.DateTimeField(auto_now=True, db_column='updatedAt'),
        ),
        migrations.AddField(
            model_name='paymentvendor',
            name='createdAt',
            field=models.DateTimeField(auto_now_add=True, db_column='createdAt', default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='paymentvendor',
            name='createdBy',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='paymentvendor',
            name='deleted',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='paymentvendor',
            name='deletedAt',
            field=models.DateTimeField(blank=True, db_column='deletedAt', null=True),
        ),
        migrations.AddField(
            model_name='paymentvendor',
            name='deletedById',
            field=models.UUIDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='paymentvendor',
            name='deletedViaCascade',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='paymentvendor',
            name='uid',
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
        migrations.AddField(
            model_name='paymentvendor',
            name='updatedAt',
            field=models.DateTimeField(auto_now=True, db_column='updatedAt'),
        ),
        migrations.AddField(
            model_name='product',
            name='createdAt',
            field=models.DateTimeField(auto_now_add=True, db_column='createdAt', default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='product',
            name='createdBy',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='product',
            name='deleted',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='product',
            name='deletedAt',
            field=models.DateTimeField(blank=True, db_column='deletedAt', null=True),
        ),
        migrations.AddField(
            model_name='product',
            name='deletedById',
            field=models.UUIDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='product',
            name='deletedViaCascade',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='product',
            name='uid',
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
        migrations.AddField(
            model_name='product',
            name='updatedAt',
            field=models.DateTimeField(auto_now=True, db_column='updatedAt'),
        ),
        migrations.AddField(
            model_name='purchase',
            name='createdAt',
            field=models.DateTimeField(auto_now_add=True, db_column='createdAt', default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='purchase',
            name='createdBy',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='purchase',
            name='deleted',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='purchase',
            name='deletedAt',
            field=models.DateTimeField(blank=True, db_column='deletedAt', null=True),
        ),
        migrations.AddField(
            model_name='purchase',
            name='deletedById',
            field=models.UUIDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='purchase',
            name='deletedViaCascade',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='purchase',
            name='uid',
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
        migrations.AddField(
            model_name='purchase',
            name='updatedAt',
            field=models.DateTimeField(auto_now=True, db_column='updatedAt'),
        ),
        migrations.AddField(
            model_name='survey',
            name='createdAt',
            field=models.DateTimeField(auto_now_add=True, db_column='createdAt', default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='survey',
            name='createdBy',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='survey',
            name='deleted',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='survey',
            name='deletedAt',
            field=models.DateTimeField(blank=True, db_column='deletedAt', null=True),
        ),
        migrations.AddField(
            model_name='survey',
            name='deletedById',
            field=models.UUIDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='survey',
            name='deletedViaCascade',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='survey',
            name='uid',
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
        migrations.AddField(
            model_name='survey',
            name='updatedAt',
            field=models.DateTimeField(auto_now=True, db_column='updatedAt'),
        ),
        migrations.AddField(
            model_name='transactionlog',
            name='createdAt',
            field=models.DateTimeField(auto_now_add=True, db_column='createdAt', default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='transactionlog',
            name='createdBy',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='transactionlog',
            name='deleted',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='transactionlog',
            name='deletedAt',
            field=models.DateTimeField(blank=True, db_column='deletedAt', null=True),
        ),
        migrations.AddField(
            model_name='transactionlog',
            name='deletedById',
            field=models.UUIDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='transactionlog',
            name='deletedViaCascade',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='transactionlog',
            name='uid',
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
        migrations.AddField(
            model_name='transactionlog',
            name='updatedAt',
            field=models.DateTimeField(auto_now=True, db_column='updatedAt'),
        ),
        migrations.AddField(
            model_name='user',
            name='createdAt',
            field=models.DateTimeField(auto_now_add=True, db_column='createdAt', default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='user',
            name='createdBy',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='user',
            name='deleted',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='user',
            name='deletedAt',
            field=models.DateTimeField(blank=True, db_column='deletedAt', null=True),
        ),
        migrations.AddField(
            model_name='user',
            name='deletedById',
            field=models.UUIDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='user',
            name='deletedViaCascade',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='user',
            name='uid',
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
        migrations.AddField(
            model_name='user',
            name='updatedAt',
            field=models.DateTimeField(auto_now=True, db_column='updatedAt'),
        ),
        migrations.AddField(
            model_name='useraddress',
            name='createdAt',
            field=models.DateTimeField(auto_now_add=True, db_column='createdAt', default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='useraddress',
            name='createdBy',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='useraddress',
            name='deleted',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='useraddress',
            name='deletedAt',
            field=models.DateTimeField(blank=True, db_column='deletedAt', null=True),
        ),
        migrations.AddField(
            model_name='useraddress',
            name='deletedById',
            field=models.UUIDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='useraddress',
            name='deletedViaCascade',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='useraddress',
            name='uid',
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
        migrations.AddField(
            model_name='useraddress',
            name='updatedAt',
            field=models.DateTimeField(auto_now=True, db_column='updatedAt'),
        ),
        migrations.AddField(
            model_name='verification',
            name='createdAt',
            field=models.DateTimeField(auto_now_add=True, db_column='createdAt', default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='verification',
            name='createdBy',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='verification',
            name='deleted',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='verification',
            name='deletedAt',
            field=models.DateTimeField(blank=True, db_column='deletedAt', null=True),
        ),
        migrations.AddField(
            model_name='verification',
            name='deletedById',
            field=models.UUIDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='verification',
            name='deletedViaCascade',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='verification',
            name='uid',
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
        migrations.AddField(
            model_name='verification',
            name='updatedAt',
            field=models.DateTimeField(auto_now=True, db_column='updatedAt'),
        ),
        migrations.AddField(
            model_name='verificationtype',
            name='createdAt',
            field=models.DateTimeField(auto_now_add=True, db_column='createdAt', default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='verificationtype',
            name='createdBy',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='verificationtype',
            name='deleted',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='verificationtype',
            name='deletedAt',
            field=models.DateTimeField(blank=True, db_column='deletedAt', null=True),
        ),
        migrations.AddField(
            model_name='verificationtype',
            name='deletedById',
            field=models.UUIDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='verificationtype',
            name='deletedViaCascade',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='verificationtype',
            name='uid',
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
        migrations.AddField(
            model_name='verificationtype',
            name='updatedAt',
            field=models.DateTimeField(auto_now=True, db_column='updatedAt'),
        ),
        migrations.AddField(
            model_name='wallet',
            name='createdAt',
            field=models.DateTimeField(auto_now_add=True, db_column='createdAt', default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='wallet',
            name='deleted',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='wallet',
            name='deletedAt',
            field=models.DateTimeField(blank=True, db_column='deletedAt', null=True),
        ),
        migrations.AddField(
            model_name='wallet',
            name='deletedById',
            field=models.UUIDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='wallet',
            name='deletedViaCascade',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='wallet',
            name='uid',
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
        migrations.AddField(
            model_name='wallet',
            name='updatedAt',
            field=models.DateTimeField(auto_now=True, db_column='updatedAt'),
        ),
        migrations.AddField(
            model_name='wallethistory',
            name='createdAt',
            field=models.DateTimeField(auto_now_add=True, db_column='createdAt', default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='wallethistory',
            name='createdBy',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='wallethistory',
            name='deleted',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='wallethistory',
            name='deletedAt',
            field=models.DateTimeField(blank=True, db_column='deletedAt', null=True),
        ),
        migrations.AddField(
            model_name='wallethistory',
            name='deletedById',
            field=models.UUIDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='wallethistory',
            name='deletedViaCascade',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='wallethistory',
            name='uid',
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
        migrations.AddField(
            model_name='wallethistory',
            name='updatedAt',
            field=models.DateTimeField(auto_now=True, db_column='updatedAt'),
        ),
        migrations.AddField(
            model_name='workordermaterial',
            name='createdAt',
            field=models.DateTimeField(auto_now_add=True, db_column='createdAt', default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='workordermaterial',
            name='createdBy',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='workordermaterial',
            name='deleted',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='workordermaterial',
            name='deletedAt',
            field=models.DateTimeField(blank=True, db_column='deletedAt', null=True),
        ),
        migrations.AddField(
            model_name='workordermaterial',
            name='deletedById',
            field=models.UUIDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='workordermaterial',
            name='deletedViaCascade',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='workordermaterial',
            name='uid',
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
        migrations.AddField(
            model_name='workordermaterial',
            name='updatedAt',
            field=models.DateTimeField(auto_now=True, db_column='updatedAt'),
        ),
        migrations.AddField(
            model_name='workorderservice',
            name='createdAt',
            field=models.DateTimeField(auto_now_add=True, db_column='createdAt', default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='workorderservice',
            name='createdBy',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='workorderservice',
            name='deleted',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='workorderservice',
            name='deletedAt',
            field=models.DateTimeField(blank=True, db_column='deletedAt', null=True),
        ),
        migrations.AddField(
            model_name='workorderservice',
            name='deletedById',
            field=models.UUIDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='workorderservice',
            name='deletedViaCascade',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='workorderservice',
            name='uid',
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
        migrations.AddField(
            model_name='workorderservice',
            name='updatedAt',
            field=models.DateTimeField(auto_now=True, db_column='updatedAt'),
        ),
        migrations.AddField(
            model_name='workorderservicecategory',
            name='createdAt',
            field=models.DateTimeField(auto_now_add=True, db_column='createdAt', default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='workorderservicecategory',
            name='createdBy',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='workorderservicecategory',
            name='deleted',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='workorderservicecategory',
            name='deletedAt',
            field=models.DateTimeField(blank=True, db_column='deletedAt', null=True),
        ),
        migrations.AddField(
            model_name='workorderservicecategory',
            name='deletedById',
            field=models.UUIDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='workorderservicecategory',
            name='deletedViaCascade',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='workorderservicecategory',
            name='uid',
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
        migrations.AddField(
            model_name='workorderservicecategory',
            name='updatedAt',
            field=models.DateTimeField(auto_now=True, db_column='updatedAt'),
        ),
        migrations.AddField(
            model_name='workorderstatus',
            name='createdAt',
            field=models.DateTimeField(auto_now_add=True, db_column='createdAt', default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='workorderstatus',
            name='createdBy',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='workorderstatus',
            name='deleted',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='workorderstatus',
            name='deletedAt',
            field=models.DateTimeField(blank=True, db_column='deletedAt', null=True),
        ),
        migrations.AddField(
            model_name='workorderstatus',
            name='deletedById',
            field=models.UUIDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='workorderstatus',
            name='deletedViaCascade',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='workorderstatus',
            name='uid',
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
        migrations.AddField(
            model_name='workorderstatus',
            name='updatedAt',
            field=models.DateTimeField(auto_now=True, db_column='updatedAt'),
        ),
        migrations.AlterField(
            model_name='conversation',
            name='participants',
            field=models.ManyToManyField(related_name='conversations', to=settings.AUTH_USER_MODEL),
        ),
    ]
