# Generated by Django 3.2.7 on 2022-07-17 21:10

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('app', '0017_auto_20220714_0637'),
    ]

    operations = [
        migrations.RenameField(
            model_name='workorder',
            old_name='fee',
            new_name='commission',
        ),
        migrations.RemoveField(
            model_name='workorder',
            name='jobCompletedAt',
        ),
        migrations.RemoveField(
            model_name='workorder',
            name='remainingServiceCharge',
        ),
        migrations.RemoveField(
            model_name='workordermaterial',
            name='description',
        ),
        migrations.RemoveField(
            model_name='workordermaterial',
            name='item',
        ),
        migrations.RemoveField(
            model_name='workordermaterial',
            name='productName',
        ),
        migrations.AddField(
            model_name='workorder',
            name='assessmentCompletedAt',
            field=models.DateTimeField(blank=True, db_column='assessmentCompletedAt', null=True),
        ),
        migrations.AddField(
            model_name='workorder',
            name='jobCompletedByAgentAt',
            field=models.DateTimeField(blank=True, db_column='jobCompletedByAgentAt', null=True),
        ),
        migrations.AddField(
            model_name='workorder',
            name='jobCompletedByCustomerAt',
            field=models.DateTimeField(blank=True, db_column='jobCompletedByCustomerAt', null=True),
        ),
        migrations.AddField(
            model_name='workorder',
            name='paymentCompletedAt',
            field=models.DateTimeField(blank=True, db_column='paymentCompletedAt', null=True),
        ),
        migrations.AddField(
            model_name='workordermaterial',
            name='product',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='app.product'),
        ),
        migrations.AddField(
            model_name='workordermaterial',
            name='total',
            field=models.DecimalField(decimal_places=2, default=0, max_digits=15),
        ),
        migrations.AddField(
            model_name='workorderservicecategory',
            name='minimumServiceCharge',
            field=models.DecimalField(db_column='minimumServiceCharge', decimal_places=2, default=1, max_digits=15),
        ),
        migrations.AlterField(
            model_name='workorderservicecategory',
            name='chargeType',
            field=models.CharField(choices=[('fixed', 'fixed'), ('percent', 'percent')], db_column='chargeType', default='fixed', max_length=15),
        ),
        migrations.AlterField(
            model_name='workorderservicecategory',
            name='serviceCharge',
            field=models.DecimalField(db_column='serviceCharge', decimal_places=2, default=1, max_digits=15),
        ),
    ]
